betty.ancestry.gender package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.gender package

## Submodules

- betty.ancestry.gender.genders module
  - `Female`
  - `Male`
  - `NonBinary`
  - `Unknown`

## Module contents

Provide Betty’s ancestry genders.

betty.ancestry.gender.GENDER_REPOSITORY: PluginRepository[Gender] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The gender plugin repository.

  Read more about Gender plugins.

class betty.ancestry.gender.Gender

  Bases: `Plugin`

  Define a gender.

  Read more about Gender plugins.

  To test your own subclasses, use `betty.test_utils.ancestry.gender.GenderTestBase`.